@@ -7,32 +7,25 @@ use Mojo::Base -base;
 has 'literal_uri' => '';
 has 'resolved_uri' => '';
 has 'referrer' => '';
-has 'depth' => 0;
-has 'additional_props' => sub { {} };
 has 'redirect_history' => sub { [] };
-has 'method' => 'get';
+has 'method';
 has 'tx_params';
 
 sub clone {
     my $self = shift;
-    my $new = __PACKAGE__->new(%$self);
-    $new->additional_props({%{$self->additional_props}});
-    return $new;
+    return __PACKAGE__->new(%$self);
 }
 
 sub child {
     my $self = shift;
-    my $child = __PACKAGE__->new(@_,
-                                referrer => $self, depth => $self->{depth} + 1);
+    my $child = __PACKAGE__->new(@_, referrer => $self);
     return $child;
 }
 
-sub add_props {
+sub depth {
     my $self = shift;
-    my %hash = scalar @_ == 1 ? %{$_[0]} : @_;
-    for (keys %hash) {
-        $self->additional_props->{$_} = $hash{$_};
-    }
+    return $self->referrer->depth + 1 if $self->referrer;
+    return 0;
 }
 
 sub redirect {
@@ -66,22 +59,35 @@ This class represents a single crawler job.
 
 =head2 literal_uri
 
+A L<Mojo::URL> instance of the literal URL that has appeared in the referrer
+document.
+
 =head2 resolved_uri
 
+A L<Mojo::URL> instance of the resolved URL.
+
 =head2 referrer
 
-=head2 depth
-
-=head2 additional_props
-
-Add propeties for job.
-
-    $job->additional_props({key1 => $value1, key2 => $value2});
+A job instance that has referred the URL.
 
 =head2 redirect_history
 
+An array reference that contains URLs of redirect history.
+
+=head2 method
+
+HTTP request method such as get or post.
+
+=head2 tx_params
+
+A hash reference that contains params for L<Mojo::Transaction>.
+
 =head1 METHODS
 
+=head2 clone
+
+Clones the job.
+
 =head2 child
 
 Initiate a child job by parent job. The parent uri is set to child referrer.
@@ -90,7 +96,9 @@ Initiate a child job by parent job. The parent uri is set to child referrer.
     my $job2 = $job1->child(resolved_uri => 'http://a/2');
     say $job2->referrer # 'http://a/1'
 
-=head2 add_props
+=head2 depth
+
+Counts the depth of job in referrer series.
 
 =head2 redirect
 
@@ -102,6 +110,10 @@ Replaces the resolved URI and history at once.
     say $job->resolved_uri # $url2
     say $job->redirect_history # [$url1, $url3]
 
+=head2 original_uri
+
+Returns the original URI of redirected job.
+
 =head1 AUTHOR
 
 Sugama Keita, E<lt>sugama@jamadam.comE<gt>
